(module iup-base
  (ihandle->pointer pointer->ihandle ihandle-list->pointer-vector ihandle?
   istatus->integer integer->istatus
   iname->string string->iname
   thread-watchdog iup-version load/led
   attribute attributes attribute-set! attribute-reset!
   handle-name handle-name-set! handle-ref
   main-loop main-loop-step main-loop-level main-loop-exit main-loop-flush
   callback callback-set!
   make-constructor-procedure optional-args
   create destroy! map-peer! unmap-peer!
   class-name class-type save-attributes!
   parent parent-dialog sibling
   child-add! child-remove! child-move!
   child-ref child-pos child-count
   :children children
   refresh redraw
   child-x/y->pos
   show hide
   dialog
   fill gridbox hbox vbox zbox cbox sbox
   radio normalizer backgroundbox detachbox expandbox scrollbox split
   image/palette image/rgb image/rgba image/file image/blob image-save
   current-focus focus-next focus-previous
   menu menu-item menu-separator
   clipboard timer send-url)
  (import
    scheme
    (chicken base)
    (chicken gc)
    (chicken fixnum)
    (chicken blob)
    (chicken string)
    (chicken keyword)
    (chicken random)
    (chicken format)
    (chicken irregex)
    (chicken condition)
    (chicken memory)
    (chicken foreign)
    srfi-1 srfi-13 srfi-42 srfi-69
    miscmacros)
  (include "iup-base.scm"))

(module iup-controls
  (canvas
   frame tabs
   label link button toggle
   spin spinbox valuator
   textbox listbox treebox
   calendar date-picker
   progress-bar
   matrix matrix-listbox cells
   color-bar color-browser
   dial)
  (import
    scheme
    (chicken base)
    (chicken foreign)
    iup-base)
  (include "iup-controls.scm"))

(module iup-dialogs
  (file-dialog message-dialog color-dialog font-dialog progress-dialog
   layout-dialog element-properties-dialog)
  (import
    scheme
    (chicken base)
    (chicken foreign)
    iup-base)
  (include "iup-dialogs.scm"))

(module iup-glcanvas
  (glcanvas
   call-with-glcanvas glcanvas-is-current?
   glcanvas-palette-set! glcanvas-font-set!)
  (import
    scheme
    (chicken base)
    (chicken foreign)
    iup-base)
  (cond-expand
   [disable-iup-glcanvas
    (define (call-with-glcanvas handle proc #!key [swap? #f] [sync? #f])
      (void))
    (define (glcanvas-is-current? handle)
      #f)
    (define (glcanvas-palette-set! handle index r g b)
      (error 'glcanvas-palette-set! "function not implemented" handle index r g b))
    (define (glcanvas-font-set! handle first count base)
      (error 'glcanvas-font-set! "function not implemented" handle first count base))]
   [else
    (include "iup-glcanvas.scm")]))

(module iup-glcontrols
  (glcanvasbox glsubcanvas
   call-with-glcanvas glcanvas-is-current?
   glcanvas-palette-set! glcanvas-font-set!
   glframe glexpander glscrollbox glsizebox
   glseparator gllabel gllink glbutton gltoggle
   glvaluator glprogress-bar)
  (import
    scheme
    (chicken base)
    (chicken foreign)
    iup-base iup-glcanvas)
  (cond-expand
   [(or disable-iup-glcanvas disable-iup-glcontrols)
    (define (glcanvasbox . args)
      (apply error 'glcanvasbox "function not implemented" args))
    (define (glsubcanvas . args)
      (apply error 'glsubcanvas "function not implemented" args))
    (define (glframe . args)
      (apply error 'glframe "function not implemented" args))
    (define (glexpander . args)
      (apply error 'glexpander "function not implemented" args))
    (define (glscrollbox . args)
      (apply error 'glscrollbox "function not implemented" args))
    (define (glsizebox . args)
      (apply error 'glsizebox "function not implemented" args))
    (define (glseparator . args)
      (apply error 'glseparator "function not implemented" args))
    (define (gllabel . args)
      (apply error 'gllabel "function not implemented" args))
    (define (gllink . args)
      (apply error 'gllink "function not implemented" args))
    (define (glbutton . args)
      (apply error 'glbutton "function not implemented" args))
    (define (gltoggle . args)
      (apply error 'gltoggle "function not implemented" args))
    (define (glvaluator . args)
      (apply error 'glvaluator "function not implemented" args))
    (define (glprogress-bar . args)
      (apply error 'glprogress-bar "function not implemented" args))]
   [else
    (include "iup-glcontrols.scm")]))

(module iup-plot
  (plot
   call-with-plot plot-add!
   plot-x/y->pixel-x/y
   plot-paint-to)
  (import
    scheme
    (chicken base)
    (chicken foreign)
    iup-base)
  (cond-expand
   [disable-iup-plot
    (define (plot . args)
      (apply error 'plot "function not implemented" args))
    (define (call-with-plot handle proc #!key [x-string? #f])
      (void))
    (define (plot-add! handle x y #!optional [sample-index #f] [index #f])
      (error 'plot-add! "function not implemented" handle x y sample-index index))
    (define (plot-x/y->pixel-x/y handle x y)
      (values x y))
    (define (plot-paint-to handle canvas)
      (error 'plot-paint-to "function not implemented" handle canvas))]
   [else
    (include "iup-plot.scm")]))

(module iup-mglplot
  (mglplot mgllabel
   call-with-mglplot mglplot-add!
   mglplot-x/y/z->pixel-x/y
   mglplot-paint-to)
  (import
    scheme
    (chicken base)
    (chicken foreign)
    iup-base)
  (cond-expand
   [disable-iup-mglplot
    (define (mglplot . args)
      (apply error 'mglplot "function not implemented" args))
    (define (mgllabel . args)
      (apply error 'mgllabel "function not implemented" args))
    (define (call-with-mglplot handle proc #!key [dimension 2])
      (void))
    (define (mglplot-add! handle x y #!optional [z #f] [sample-index #f] [index #f])
      (error 'mglplot-add! "function not implemented" handle x y z sample-index index))
    (define (mglplot-x/y/z->pixel-x/y handle x y #!optional z)
      (values x y))
    (define (mglplot-paint-to handle format file #!optional [width 0] [height 0] [dpi 0.0])
      (error 'mglplot-paint-to "function not implemented" handle format file width height dpi))]
   [else
    (include "iup-mglplot.scm")]))

(module iup-pplot
  (pplot
   call-with-pplot pplot-add!
   pplot-x/y->pixel-x/y
   pplot-paint-to)
  (import
    scheme
    (chicken base)
    (chicken foreign)
    iup-base)
  (cond-expand
   [enable-iup-pplot
    (include "iup-pplot.scm")]
   [else
    (define (pplot . args)
      (apply error 'pplot "function not implemented" args))
    (define (call-with-pplot handle proc #!key [x-string? #f])
      (void))
    (define (pplot-add! handle x y #!optional [sample-index #f] [index #f])
      (error 'pplot-add! "function not implemented" handle x y sample-index index))
    (define (pplot-x/y->pixel-x/y handle x y)
      (values x y))
    (define (pplot-paint-to handle canvas)
      (error 'pplot-paint-to "function not implemented" handle canvas))]))

(module iup-scintilla
  (scintilla)
  (import
    scheme
    (chicken base)
    (chicken foreign)
    iup-base)
  (cond-expand
   [disable-iup-scintilla
    (define (scintilla . args)
      (apply error 'scintilla "function not implemented" args))]
   [else
    (include "iup-scintilla.scm")]))

(module iup-web
  (web-browser)
  (import
    scheme
    (chicken base)
    (chicken foreign)
    iup-base)
  (cond-expand
   [disable-iup-web
    (define (web-browser . args)
      (apply error 'web-browser "function not implemented" args))]
   [else
    (include "iup-web.scm")]))

(module iup-ole
  (ole-control)
  (import
    scheme
    (chicken base)
    (chicken foreign)
    iup-base)
  (cond-expand
   [enable-iup-ole
    (include "iup-ole.scm")]
   [else
    (define (ole-control . args)
      (apply error 'ole-control "function not implemented" args))]))

(module iup-config
  (config
   config-load! config-save!
   config-recent-menu config-recent-update!
   config-dialog-show config-dialog-update!)
  (import
    scheme
    (chicken base)
    (chicken condition)
    (chicken foreign)
    iup-base)
  (cond-expand
   [disable-iup-config
    (define (config . args)
      (apply error 'config "function not implemented" args))
    (define (config-load! handle)
      (void))
    (define (config-save! handle)
      (void))
    (define (config-recent-menu . args)
      (apply error 'config-recent-menu "function not implemented" args))
    (define (config-recent-update! handle item)
      (void))
    (define (config-dialog-show handle dialog name)
      (show dialog))
    (define (config-dialog-update! handle dialog name)
      (void))]
   [else
    (include "iup-config.scm")]))

(module iup
  ()
  (import
    scheme
    (chicken base)
    (chicken module))
  (reexport
    (except iup-base
      ihandle->pointer pointer->ihandle ihandle-list->pointer-vector
      istatus->integer integer->istatus
      iname->string string->iname
      make-constructor-procedure optional-args)
    iup-controls
    iup-dialogs))

;; vim: set ai et ts=2 sts=2 sw=2: ;;
